@@ -158,10 +158,10 @@ namespace openshot
 		~Frame();
 
 		/// Add (or replace) pixel data to the frame (based on a solid color)
-		void AddColor(int width, int height, string color);
+		void AddColor(int new_width, int new_height, string color);
 
 		/// Add (or replace) pixel data to the frame
-		void AddImage(int width, int height, int bytes_per_pixel, QImage::Format type, const unsigned char *pixels_);
+		void AddImage(int new_width, int new_height, int bytes_per_pixel, QImage::Format type, const unsigned char *pixels_);
 
 		/// Add (or replace) pixel data to the frame
 		void AddImage(tr1::shared_ptr<QImage> new_image);
@@ -276,7 +276,7 @@ namespace openshot
 		void Save(string path, float scale, string format="PNG", int quality=100);
 
 		/// Set frame number
-		void SetFrameNumber(int number);
+		void SetFrameNumber(long int number);
 
 		/// Set Pixel Aspect Ratio
 		void SetPixelRatio(int num, int den);
